from bson import ObjectId
from pymongo import MongoClient
from datetime import datetime


class EncoursDao:
    client = MongoClient('localhost', 27017)

    ## extraction d'une base de données. Si elle n'existe pas, elle esst créée
    base_donnees = client.squelette

    ## Fonction qui permet de savoir si un contenu en cours à fait l'objet d'une demande de publication
    # @param idEnCours l'id du contenu en cours
    # @param l'auteur l'auteur potentiel de la demande de publication
    def is_en_cours_demande(self, idEnCours, auteur):
        return self.base_donnees.demandesPub.find({"id": idEnCours} and {"auteurDemande": auteur}).count() != 0

    ## récupérer l'auteur initial d'un contenu en cours (peut être l'auteur effectuant la modification ou non)
    # @param idContenuEnCours l'id du contenu en cours de modification
    # @return l'auteur intial du contenu en cours
    def get_auteur_origine_contenu_en_cours(self, id_contenu_en_cours):
        id_contenu = self.base_donnees.encours.find_one({"_id": ObjectId(id_contenu_en_cours)})["reference"]
        return self.base_donnees.contenu.find_one({"_id": id_contenu})["auteur"]

    ## récupérer l'id initial d'un contenu en cours (peut être l'auteur effectuant la modification ou non)
    # @param idContenuEnCours l'id du contenu en cours de modification
    # @return l'id intial du contenu en cours
    def get_id_origine_contenu_en_cours(self, id_contenu_en_cours):
        return self.base_donnees.encours.find_one({"_id": ObjectId(id_contenu_en_cours)})["reference"]

    ## permet de récupérer tous les contenus en cours pour un auteur
    # @param auteur le nom de l'auteur
    # @return les contenus en cours de l'auteur
    def get_contenus_en_cours_auteur(self, auteur):
        return self.base_donnees.encours.find({"auteur": auteur})

    ## récupérer un contenu en cours
    # @param idContenuEnCours l'id du contenu en cours de modification
    # @return le contenu en cours
    def get_contenu_en_cours(self, id_contenu_en_cours):
        # id_contenu = Utils.getIdContenuAssocieAUnEnCours(idContenuEnCours)
        return self.base_donnees.encours.find_one({"idContenuEC": id_contenu_en_cours})

    ## supprimer un contenu en cours
    # @param idContenu id du contenu  de la reference a supprimer
    def supprimer_contenu_en_cours(self, idContenuEnCours):

        self.base_donnees.encours.delete_one({"reference": ObjectId(idContenuEnCours)})

    ## supprimer un contenu en cours avec l'id
    # @param idContenuEnCours id du contenu a supprimer
    def supprimer_contenu_en_cours_via_id(self, idContenuEnCours):

        self.base_donnees.encours.delete_one({"_id": ObjectId(idContenuEnCours)})


    ## création d'un contenu en cours
    # @param version la version du contenu d'origine
    # @param nomBranche -> plus utile.
    def creer_en_cours(self, auteur, idContenu, version):
        self.base_donnees.encours.insert_one(
            {"date": datetime.now().strftime("%d/%m/%y"), "auteur": auteur,
             "reference": ObjectId(idContenu), "version": version})

    ## création d'un contenu en cours, dans l'état refuse
    # @param version la version du contenu d'origine
    # @param nomBranche -> plus utile.
    def creer_en_cours_refuse(self, auteur, idContenu, version):
        self.base_donnees.encours.insert_one(
            {"date": datetime.now().strftime("%d/%m/%y"), "auteur": auteur,
             "reference": ObjectId(idContenu), "version": version, "etat": "refuse"})
